==> libgnome-2.20.1.1-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgnome-2.so.0 )
( cd usr/lib ; ln -sf libgnome-2.so.0.1999.2 libgnome-2.so.0 )
( cd usr/lib ; rm -rf libgnome-2.so )
( cd usr/lib ; ln -sf libgnome-2.so.0.1999.2 libgnome-2.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_accessibility_keyboard.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_accessibility_startup.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_at_mobility.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_at_visual.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_browser.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_help_viewer.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_terminal.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_window_manager.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_background.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_file_views.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_interface.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_peripherals_keyboard.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_peripherals_mouse.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_sound.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_thumbnailers.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_typing_break.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/update-mime-database ]; then
	usr/bin/update-mime-database usr/share/mime/ &> /dev/null
fi

==> libgnome-2.22.0-i586-2gsb.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgnome-2.so )
( cd usr/lib ; ln -sf libgnome-2.so.0.2200.0 libgnome-2.so )
( cd usr/lib ; rm -rf libgnome-2.so.0 )
( cd usr/lib ; ln -sf libgnome-2.so.0.2200.0 libgnome-2.so.0 )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_accessibility_keyboard.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_accessibility_startup.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_at_mobility.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_at_visual.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_browser.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_office.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_terminal.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_applications_window_manager.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_background.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_file_views.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_interface.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_peripherals_keyboard.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_peripherals_mouse.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_sound.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_thumbnailers.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_typing_break.schemas >/dev/null 2>&1
fi
# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

if [ -x usr/bin/update-mime-database ]; then
	usr/bin/update-mime-database usr/share/mime/ &> /dev/null
fi
